@@ -35,3 +35,8 @@ do
 }')
     jq -r ".[\"${file}\"]" tmp/main.json | gojsontoyaml > "${prefix}/${fullfile}.yaml"
 done
+
+# Produce dashboard definitions in format understandable by CVO (it doesn't accept ConfigMapList)
+grep -E -v '^apiVersion: v1|^items:|^kind: ConfigMapList' "assets/grafana/console-dashboard-definitions.yaml" | sed 's/^\ \ //g;s/- apiVersion: v1/---\napiVersion: v1/g' > "manifests/0000_90_cluster_monitoring_operator_01-dashboards.yaml"
+rm -f "assets/grafana/console-dashboard-definitions.yaml"
+
